An easy to use and expand framework for Reinforcement Learning experimentation and run simulation.

Full read.me can be found here https://github.com/PriestTheBeast/RLRunner. Excerpt of it is below.

I had some difficulty naming this project and ended up choosing RL runner, but some other options would be RL Agent runner, Agent comparator, RL Running System, Agent Running system, etc...

In the past I've wanted, both academically and for fun experimentations, to compare different RL agents with different parameters and different environments, but didn't find anything except gym, which only helped with environments. So I made my own system for performing runs with different agents and environments, adding other features along as I found necessary and useful. In the end it was a mess of code, but code that could be useful for other people that might need what I also needed. 

So, I wrote this RL running framework from the ground up with this in mind: as much freedom as possible for experimenting and doing what people want while providing a good foundation for building upon it.

I made this to be as whatever you might need as possible.

You can install as a library and quickly have a system for comparing some agents and experiment in RL, 
or even take the package from here, slam it in your project and redesign anything you want from it.

Sharing your work should also be simpler when both people use the same underlying system, no matter if it's an original agent, env or anything else.

In case you are a teacher you could even take this runner, or make one from it custom to your needs, and give your students a good foundation to build upon and learn. You can even directly compare their agents under the same rules and make fun competitions.

I hope this can be useful to people :)
